@@ -27,7 +27,7 @@ from rdkit.Chem import (
     SANITIZE_CLEANUP,
     SANITIZE_CLEANUPCHIRALITY,
     SANITIZE_FINDRADICALS,MolToMolBlock,
-    MolToMolBlock, MolFromMolBlock
+    MolToMolBlock, MolFromMolBlock, RemoveStereochemistry
 
 )
 
@@ -193,7 +193,7 @@ class MurckoRingFragmenter(Fragmenter):
                     if len(shared) == 1:
                         bond = edit.GetBondWithIdx(shared.pop())
                         bond.SetBondType(BondType.DOUBLE)
-                        print('DOUBLE')
+                        #print('DOUBLE')
 
             # Remove collected atoms and bonds
             for bix in remove_bonds:
@@ -799,11 +799,19 @@ MolToSmiles
     if not scaffold:
         scaffold = get_murcko_scaffold(mol)
     annotated = rdmolops.ReplaceSidechains(mol, scaffold)
+    RemoveStereochemistry(annotated)
     if as_mol:
         return annotated
     if annotated is None:
         return ''
-    return MolToMolBlock(annotated)
+    #print('Processing mol 4a');
+    blk = MolToMolBlock(annotated)
+    try:
+        blk = MolToMolBlock(annotated)
+    except :
+        blk = MolToMolBlock(mol) #my changes severe
+        print('ERROR ANNOTATION', blk);
+    return blk;
 
 
 @suppress_rdlogger()
